/*
   dirio.c

   This is for openVMS with EGCS 1.1 (based on GNU C 2.8)

   Copyright  by Klaus Kmpf (kkaempf@rmi.de) 1998

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that: (1) source code distributions
   retain the above copyright notice and this paragraph in its entirety, (2)
   distributions including binary code include the above copyright notice and
   this paragraph in its entirety in the documentation or other materials
   provided with the distribution, and (3) all advertising materials mentioning
   features or use of this software display the following acknowledgement:
   ``This product includes software developed by Klaus Kmpf, Nrnberg,
   Germany.''
   THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
   WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

 */

#include <stdio.h>
#ifdef __DECC
#include <starlet.h>
#endif
#include <descrip.h>
#include <rms.h>
#include <iodef.h>
#include <atrdef.h>
#include <fibdef.h>
#include "dirent.h"

DIR *opendir(char *dspec)
{
  static struct FAB *dfab;
  struct NAM *dnam;
  char *searchspec;

  if ((dfab = (struct FAB *)malloc (sizeof (struct FAB))) == NULL)
    return (NULL);

  if ((dnam = (struct NAM *)malloc (sizeof (struct NAM))) == NULL)
    {
      free (dfab);
      return (NULL);
    }
  if ((searchspec = (char *)malloc (MAXNAMLEN+1)) == NULL)
    {
      free (dfab);
      free (dnam);
      return (NULL);
   }

  sprintf (searchspec,"%s*.*;",dspec);

  *dfab = cc$rms_fab;
  dfab->fab$l_fna = searchspec;
  dfab->fab$b_fns = strlen (searchspec);
  dfab->fab$l_nam = dnam;

  *dnam = cc$rms_nam;
  dnam->nam$l_esa = searchspec;
  dnam->nam$b_ess = MAXNAMLEN;

  if (!(sys$parse (dfab) & 1))
    {
      free (dfab);
      free (dnam);
      free (searchspec);
      return (NULL);
   }

  return (dfab);
}

#include <ctype.h>
#define uppercasify(str) { char *tmp; for(tmp = (str); *tmp != '\0'; tmp++) if(islower(*tmp)) *tmp = toupper(*tmp); }

struct direct *readdir(DIR *dfd)
{
  static struct direct *dentry;
  static char resultspec[MAXNAMLEN+1];
  int i;

  if ((dentry = (struct direct *)malloc (sizeof (struct direct))) == NULL)
    {
      return(NULL);
    }

  dfd->fab$l_nam->nam$l_rsa = resultspec;
  dfd->fab$l_nam->nam$b_rss = MAXNAMLEN;

  if (!((i = sys$search (dfd)) & 1))
    {
      free (dentry);
      return (NULL);
    }

  dentry->d_off = 0;
  if (dfd->fab$l_nam->nam$w_fid == 0)
    dentry->d_fileno = 1;
  else
    dentry->d_fileno = dfd->fab$l_nam->nam$w_fid[0]
			 +dfd->fab$l_nam->nam$w_fid[1]<<16;
  dentry->d_reclen = sizeof (struct direct);
  dentry->d_namlen = dfd->fab$l_nam->nam$b_name+dfd->fab$l_nam->nam$b_type;
  strncpy (dentry->d_name,dfd->fab$l_nam->nam$l_name, dentry->d_namlen);
  dentry->d_name[dentry->d_namlen] = '\0';
  uppercasify(dentry->d_name);

  return(dentry);
}

closedir(DIR *dfd)
{
  if (dfd != NULL)
    {
      if (dfd->fab$l_nam != NULL)
        free (dfd->fab$l_nam->nam$l_esa);
      free (dfd->fab$l_nam);
      free (dfd);
    }
}

/* EOF */
