/*
  execr.c

  Reentrant versions of execution system calls.

   This is for openVMS with EGCS 1.1 (based on GNU C 2.8)

   Copyright  by Klaus Kmpf (kkaempf@rmi.de) 1998

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that: (1) source code distributions
   retain the above copyright notice and this paragraph in its entirety, (2)
   distributions including binary code include the above copyright notice and
   this paragraph in its entirety in the documentation or other materials
   provided with the distribution, and (3) all advertising materials mentioning
   features or use of this software display the following acknowledgement:
   ``This product includes software developed by Klaus Kmpf, Nrnberg,
   Germany.''
   THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
   WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

  */

#include <reent.h>
#include <unistd.h>
#include <_syslist.h>
#include <errno.h>

/* We use the errno variable used by the system dependent layer.  */
#undef errno
extern int errno;

/*
FUNCTION
	<<_fork_r>>---Reentrant version of fork
	
INDEX
	_fork_r

ANSI_SYNOPSIS
	#include <reent.h>
	int _fork_r(struct _reent *<[ptr]>);

TRAD_SYNOPSIS
	#include <reent.h>
	int _fork_r(<[ptr]>)
	struct _reent *<[ptr]>;

DESCRIPTION
	This is a reentrant version of <<fork>>.  It
	takes a pointer to the global data block, which holds
	<<errno>>.
*/

int
_fork_r (ptr)
     struct _reent *ptr;
{
  ptr->_errno = EAGAIN;
  return -1;
}


/*
FUNCTION
	<<_wait_r>>---Reentrant version of wait
	
INDEX
	_wait_r

ANSI_SYNOPSIS
	#include <reent.h>
	int _wait_r(struct _reent *<[ptr]>, int *<[status]>);

TRAD_SYNOPSIS
	#include <reent.h>
	int _wait_r(<[ptr]>, <[status]>)
	struct _reent *<[ptr]>;
	int *<[status]>;

DESCRIPTION
	This is a reentrant version of <<wait>>.  It
	takes a pointer to the global data block, which holds
	<<errno>>.
*/

int
_wait_r (ptr, status)
     struct _reent *ptr;
     int *status;
{
  ptr->_errno = ECHILD;
  return -1;
}
