/*
   reent.c

   definition of impure data.

   This is for openVMS with EGCS 1.1 (based on GNU C 2.8)

   Copyright  by Klaus Kmpf (kkaempf@rmi.de) 1998

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that: (1) source code distributions
   retain the above copyright notice and this paragraph in its entirety, (2)
   distributions including binary code include the above copyright notice and
   this paragraph in its entirety in the documentation or other materials
   provided with the distribution, and (3) all advertising materials mentioning
   features or use of this software display the following acknowledgement:
   ``This product includes software developed by Klaus Kmpf, Nrnberg,
   Germany.''
   THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
   WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

 */
/*
FUNCTION
	<<reent>>---definition of impure data.
	
INDEX
	reent

DESCRIPTION
	This module defines the impure data area used by the
	non-rentrant functions, such as strtok.
*/

#include <reent.h>

/* Interim cleanup code */

void
cleanup_glue (ptr, glue)
     struct _reent *ptr;
     struct _glue *glue;
{
  /* Have to reclaim these in reverse order: */
  if (glue->_next)
    cleanup_glue (ptr, glue->_next);

  _free_r (ptr, glue);
}

void
_reclaim_reent (ptr)
     struct _reent *ptr;
{
  if (ptr != _impure_ptr)
    {
      /* used by mprec routines. */
      if (ptr->_freelist)
	{
	  int i;
	  for (i = 0; i < 15 /* _Kmax */; i++) 
	    {
	      struct _Bigint *thisone, *nextone;
	
	      nextone = ptr->_freelist[i];
	      while (nextone)
		{
		  thisone = nextone;
		  nextone = nextone->_next;
		  _free_r (ptr, thisone);
		}
	    }    

	  _free_r (ptr, ptr->_freelist);
	}

      /* atexit stuff */
      if ((ptr->_atexit) && (ptr->_atexit != &ptr->_atexit0))
	{
	  struct _atexit *p, *q;
	  for (p = ptr->_atexit; p != &ptr->_atexit0;)
	    {
	      q = p;
	      p = p->_next;
	      _free_r (ptr, q);
	    }
	}

      if (ptr->_cvtbuf)
	_free_r (ptr, ptr->_cvtbuf);

      if (ptr->__sdidinit)
	{
	  /* cleanup won't reclaim memory 'coz usually it's run
	     before the program exits, and who wants to wait for that? */
	  ptr->__cleanup (ptr);

	  if (ptr->__sglue._next)
	    cleanup_glue (ptr, ptr->__sglue._next);
	}

      /* Malloc memory not reclaimed; no good way to return memory anyway. */

    }
}

