/*

   signalr.c

   Reentrant versions of syscalls need to support signal/raise.

   This is for openVMS with EGCS 1.1 (based on GNU C 2.8)

   Copyright  by Klaus Kmpf (kkaempf@rmi.de) 1998

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that: (1) source code distributions
   retain the above copyright notice and this paragraph in its entirety, (2)
   distributions including binary code include the above copyright notice and
   this paragraph in its entirety in the documentation or other materials
   provided with the distribution, and (3) all advertising materials mentioning
   features or use of this software display the following acknowledgement:
   ``This product includes software developed by Klaus Kmpf, Nrnberg,
   Germany.''
   THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
   WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

  */

#include <reent.h>
#include <_syslist.h>
#include <errno.h>

/* We use the errno variable used by the system dependent layer.  */
#undef errno
extern int errno;

/*
FUNCTION
	<<_kill_r>>---Reentrant version of kill
	
INDEX
	_kill_r

ANSI_SYNOPSIS
	#include <reent.h>
	int _kill_r(struct _reent *<[ptr]>, int <[pid]>, int <[sig]>);

TRAD_SYNOPSIS
	#include <reent.h>
	int _kill_r(<[ptr]>, <[pid]>, <[sig]>)
	struct _reent *<[ptr]>;
	int <[pid]>;
	int <[sig]>;

DESCRIPTION
	This is a reentrant version of <<kill>>.  It
	takes a pointer to the global data block, which holds
	<<errno>>.
*/

int
_kill_r (ptr, pid, sig)
     struct _reent *ptr;
     int pid;
     int sig;
{
  ptr->_errno = EINVAL;
  return -1;
}


/*
FUNCTION
	<<_getpid_r>>---Reentrant version of getpid
	
INDEX
	_getpid_r

ANSI_SYNOPSIS
	#include <reent.h>
	int _getpid_r(struct _reent *<[ptr]>);

TRAD_SYNOPSIS
	#include <reent.h>
	int _getpid_r(<[ptr]>)
	struct _reent *<[ptr]>;

DESCRIPTION
	This is a reentrant version of <<getpid>>.  It
	takes a pointer to the global data block, which holds
	<<errno>>.

	We never need <<errno>>, of course, but for consistency we
	still must have the reentrant pointer argument.
*/

int
_getpid_r (ptr)
     struct _reent *ptr;
{
  return 1;
}
