#define TEST 0
/*
   timeconv.c

   convert unix time <-> vms time

   This is for openVMS with EGCS 1.1 (based on GNU C 2.8)

   Copyright  by Klaus Kmpf (kkaempf@rmi.de) 1998

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that: (1) source code distributions
   retain the above copyright notice and this paragraph in its entirety, (2)
   distributions including binary code include the above copyright notice and
   this paragraph in its entirety in the documentation or other materials
   provided with the distribution, and (3) all advertising materials mentioning
   features or use of this software display the following acknowledgement:
   ``This product includes software developed by Klaus Kmpf, Nrnberg,
   Germany.''
   THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
   WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

  */

#if TEST
#include <stdio.h>
#include <stddef.h>
#include <stdlib.h>
extern void SYS$NUMTIM();
extern void SYS$GETTIM();
#endif

#include <sys/types.h>
#include <time.h>

time_t
_vmst2unixt (unsigned long long vmst, long *usec)
{
  time_t unixt;

  if (usec)
    *usec = (long)((vmst % 10000000LL) / 1000LL);

  unixt = (vmst-0x7c95674beca540LL) / 10000000LL;

#ifdef DEMOEND
  if (unixt > DEMOEND)
    exit (8596);
#endif

  return unixt;
}


long long
_unixt2vmst (time_t unixt, long usec)
{
  long long vmst;

  vmst = unixt * 10000000LL + 0x7c95674beca540LL + usec * 1000LL;

  return vmst;
}


#if TEST
time_t
vmst2unixtx (unsigned long long vmst, long *usec)
{
  time_t unixt;

  struct _vmstimebuf {
    unsigned short year;
    unsigned short month;
    unsigned short day;
    unsigned short hours;
    unsigned short minutes;   
    unsigned short seconds;
    unsigned short centiseconds;
  } vmstimebuf;


#define BASE_YEAR              1970
#define DAYS_UPTO_1970       719469
#define ONE_SECOND                1
#define ONE_MINUTE               60
#define ONE_HOUR           (60 * 60)
#define ONE_DAY      (24 * ONE_HOUR)


  SYS$NUMTIM (&vmstimebuf, &vmst);

#if TEST
  printf ("vmst2unixt %ld0000000\n", (long)(vmst/10000000LL));
  printf ("%2d.%02d.%04d %02d:%02d:%02d.%d\n",
    vmstimebuf.day, vmstimebuf.month, vmstimebuf.year,
    vmstimebuf.hours, vmstimebuf.minutes, vmstimebuf.seconds, vmstimebuf.centiseconds);
#endif

  unixt = 0;

  /* return zero if the date is before 1970 */

  if (vmstimebuf.year >= BASE_YEAR)
    {
      /* convert january -> november  */
      if (vmstimebuf.month > 2)
	{
	  vmstimebuf.month -= 3;
	}
      else
	{   
	  vmstimebuf.month += 9;
	  --vmstimebuf.year;
	}
      unixt = 146097 * (vmstimebuf.year/100) / 4 +
		1461 * (vmstimebuf.year%100) / 4 +
		(153 * vmstimebuf.month + 2) / 5 +
		vmstimebuf.day - DAYS_UPTO_1970;
      unixt *= ONE_DAY;
      unixt += vmstimebuf.seconds * ONE_SECOND;
      unixt += vmstimebuf.minutes * ONE_MINUTE;
      unixt += vmstimebuf.hours   * ONE_HOUR;
    }

  if (usec)
    *usec = vmstimebuf.centiseconds * 100000;

#if TEST
  printf ("-> unixt %ld\n", unixt);
  if (usec) printf ("   usec %ld\n", *usec);
#endif

  return unixt;
}
#endif


#if TEST
int
main (int argc, char *argv[])
{
  unsigned long long vmst;
  time_t unixt;
  long usec;

  if (argc == 2)
    vmst = atol (argv[1]) * 10000000LL;
  else if (argc == 3)
    vmst = (((long long)atol (argv[1])) << 32) + atol (argv[2]);
  else
    SYS$GETTIM (&vmst);

  printf ("vmst %ld %ld\n", (long)((vmst>>32) & 0xffffffff), (long)(vmst & 0xffffffff));
  printf ("vmst %lx %08lx\n", (long)((vmst>>32) & 0xffffffff), (long)(vmst & 0xffffffff));

  unixt = vmst2unixtx (vmst, &usec);

  printf ("unixt %ld, usec %ld\n", unixt, usec);

  return 0;
}
#endif
